%
%   This function transforms the interpolation data for the
%    multiple Nevanlinna-Pick interpolation problem subjected
%    to the bilinear transformation
%
%              az + b                -du + b
%       u --> --------   <==>   z = --------- 
%              cz + d                 cu - a
%
%   Input:  domaintrans  -  Transformation parameters
%           interdata    -  Interpolation data
%
%   Output: interdatanew  -  New interpolation data
%
%   Note: the underlying function bilineardatalow considers the 
%          transformation from  z to u.
%
function interdatanew = bilineardomaindata(domaintrans,interdata)

for k = 1:interdata.ntilde
    
    [ z(k) w{k} ] = bilineardomaindatalow(-domaintrans.d, ...
        domaintrans.b,domaintrans.c,-domaintrans.a,interdata.z(k), ...
        interdata.w{k});
end

speczeros = [];
for s = interdata.speczeros
    if abs(s) > 1e10
        speczeros(end+1) = domaintrans.a / domaintrans.c;
    else
        speczeros(end+1) = (domaintrans.a * s + domaintrans.b) / ...
            (domaintrans.c * s + domaintrans.d);
    end
end

interdatanew = getinterdata(z,w,speczeros);