%
%   This functions generates the non-singular generalized Vandermonte matrix 
%    that transforms a to gamma coefficients:
%
%       a = V * gamma       (*)
%
%   Input: interdata - interpolation data set
%
%   Output: V     -  the matrix V in (*)
%
function V = getV(interdata)

% Construct coefficient vector
C = ones(interdata.m,1);
for k = 1:(max(interdata.mw)-1)
    vec = zeros(k,1);
    for m = 0:(interdata.m-k-1)
        vec = [ vec ; nchoosek(m+k,m) ];
    end
    C = [ C vec ];
end

% Construct generalized Vandermonte matrix
V = [];
for k = 1:interdata.ntilde
    vec = conj(interdata.z(k)).^(0:(interdata.m-1))';
    for m = 1:interdata.mw(k)
        V = [ V C(:,m).* vec ];
        vec = [ 0; vec(1:end-1) ];
    end
end